@@ -1,21 +1,13 @@
 context("simulate_migration")
 
 test_that("simulate_migration base", {
-  testthat::skip_on_os("solaris")
   testthat::expect_silent(
     vx <- simulate_admixture(migration = migration_settings(migration_rate = 0.1),
                            total_runtime = 5)
   )
-
-  testthat::expect_silent(
-    vx <- simulate_admixture(migration = migration_settings(migration_rate = 0.1),
-                             total_runtime = 5,
-                             num_threads = 2)
-  )
 })
 
 test_that("simulate_migration", {
-  testthat::skip_on_os("solaris")
   vx <- simulate_admixture(migration = migration_settings(migration_rate = 0.1),
                            total_runtime = 10)
 
